<?php
/************************************************************************
 * Mailer v0.2.1-FINAL                                Start: 08/03/2004 *
 * ===================                          Last change: 08/07/2004 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : what-list_task.php                               *
 * -------------------------------------------------------------------- *
 * Short description : List all tasks                                   *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Alle Aufgaben auflisten                          *
 * -------------------------------------------------------------------- *
 * $Revision::                                                        $ *
 * $Date::                                                            $ *
 * $Tag:: 0.2.1-FINAL                                                 $ *
 * $Author::                                                          $ *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * Copyright (c) 2009 - 2011 by Mailer Developer Team                   *
 * For more information visit: http://www.mxchange.org                  *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if ((!defined('__SECURITY')) || (!isAdmin())) {
	die();
} // END - if

// Add description as navigation point
addYouAreHereLink('admin', __FILE__);

if (!isExtensionActive('task')) {
	loadTemplate('admin_settings_saved', false, generateExtensionInactiveNotInstalledMessage('task'));
	return;
} // END - if

$whereStatement = '';
if (!isGetRequestParameterSet('type')) setGetRequestParameter('type', 'your');

switch (getRequestParameter('type')) {
	case 'your': // List only your own open (new) tasks
		$whereStatement = "`assigned_admin`=".getCurrentAdminId()." AND `status`='NEW' AND `task_type` != 'EXTENSION_UPDATE'";
		break;

	case 'updates': // List only updates assigned to you
		$whereStatement = "`assigned_admin`=".getCurrentAdminId()." AND `status`='NEW' AND `task_type`='EXTENSION_UPDATE'";
		break;

	case 'solved': // List only solved tasks assigned to you
		$whereStatement = "`assigned_admin`=".getCurrentAdminId()." AND `status`='SOLVED'";
		break;

	case 'unassigned': // List unassigned (but not deleted) tasks
		$whereStatement = "(`assigned_admin`=0 OR `assigned_admin` IS NULL) AND `status` != 'DELETED'";
		break;

	case 'deleted': // List all deleted
		$whereStatement = "`status`='DELETED'";
		break;

	case 'closed': // List all closed
		$whereStatement = "`assigned_admin`=".getCurrentAdminId()." AND `status`='CLOSED'";
		break;

	default: // Unknown type
		logDebugMessage(__FILE__, __LINE__, sprintf("Unknown task type %s detected.", getRequestParameter('type')));
		loadTemplate('admin_settings_saved', false, getMaskedMessage('ADMIN_TASK_UNKNOWN_MODE', getRequestParameter('type')));
		break;
} // END - switch

if (!empty($whereStatement)) {
	if ((isPostRequestParameterSet('assign')) && (ifPostContainsSelections())) {
		// Assign / do tasks
		loadIncludeOnce('inc/modules/admin/overview-inc.php');
		if (empty($dmy)) $dmy = '';
		outputSeletectedTasks(postRequestArray(), $dmy);
	} else {
		// Start listing tasks matching selected filter
		$result_tasks = SQL_QUERY('SELECT
	`id`, `assigned_admin`, `userid`, `task_type`, `subject`, `text`, `task_created`
FROM
	`{?_MYSQL_PREFIX?}_task_system`
WHERE
	'.$whereStatement.'
ORDER BY
	`userid` DESC,
	`task_type` DESC,
	`subject` ASC,
	`task_created` DESC',
			__FILE__, __LINE__);
		if ((ifPostContainsSelections()) && (!isDemoModeActive())) {
			// Only unassign / delete tasks when there are selected tasks posted
			if (isPostRequestParameterSet('unassign')) {
				// Unassign from tasks
				foreach (postRequestParameter('sel') as $id => $sel) {
					SQL_QUERY_ESC("UPDATE `{?_MYSQL_PREFIX?}_task_system` SET `assigned_admin`=NULL WHERE `id`=%s AND `assigned_admin`=%s LIMIT 1",
						array(bigintval($id), getCurrentAdminId()), __FILE__, __LINE__);
				} // END - foreach
			} elseif (isFormSent('delete')) {
				// Delete tasks
				foreach (postRequestParameter('sel') as $id => $sel) {
					if (getRequestParameter('type') == 'deleted') {
						// Delete task immediately
						SQL_QUERY_ESC("DELETE LOW_PRIORITY FROM `{?_MYSQL_PREFIX?}_task_system` WHERE `id`=%s LIMIT 1",
							array(bigintval($id)),__FILE__, __LINE__);
					} else {
						// Mark task as to be deleted (purged by autopurge extension)
						adminDeleteTask($id);
					}
				} // END - foreach
			} else {
				// Unknown action performed
				debug_report_bug(__FILE__, __LINE__, sprintf("Unknown task action performed. data=<pre>%s</pre>", print_r(postRequestArray(), true)));
			}

			// Update query
			$result_tasks = SQL_QUERY('SELECT
	`id`, `assigned_admin`, `userid`, `task_type`, `subject`, `text`, `task_created`
FROM
	`{?_MYSQL_PREFIX?}_task_system`
WHERE
	'.$whereStatement.'
ORDER BY
	`subject` ASC,
	`task_created` DESC', __FILE__, __LINE__);
		}

		// There are uncompleted jobs!
		$OUT = '';
		while ($content = SQL_FETCHARRAY($result_tasks)) {
			// Init infos
			$content['infos'] = '';

			// Get admin task
			$content['task_type_msg'] = '{--ADMIN_TASK_IS_' . strtoupper($content['task_type']) . '--}';

			// Generate infos
			switch ($content['task_type']) {
				case 'EXTENSION':
				case 'EXTENSION_UPDATE':
					$content['infos'] = substr($content['subject'], 1, strpos($content['subject'], ':') - 1);
					break;
			} // END - switch

			// Member assigned with task?
			if (isValidUserId($content['userid'])) {
				// Member found otherwise it's a system task
				$content['userid'] = generateUserProfileLink($content['userid']);
			} else {
				// Is a system task!
				$content['userid'] = '<em>{--ADMIN_IS_SYSTEM_TASK--}</em>';
			}

			// Prepare content
			$content = merge_array($content, array(
				'assign_admin'  => $content['assigned_admin'],
				'userid'        => $content['userid'],
				'task_type_msg' => $content['task_type_msg'],
				'task_created'  => generateDateTime($content['task_created'], 2)
			));

			// Do we have an extension task?
			if (isExtensionTask($content)) {
				// Load extension row template
				$OUT .= loadTemplate('admin_list_task_ext_rows', true, $content);
			} else {
				// Load default row template
				$OUT .= loadTemplate('admin_list_task_rows', true, $content);
			}
		} // END - while

		// Free memory
		SQL_FREERESULT($result_tasks);

		// Prepare content
		$content = array(
			'message' => '{--ADMIN_OVERVIEW_TASK_' . strtoupper(getRequestParameter('type')) . '_TYPE--}',
			'type'    => getRequestParameter('type'),
			'rows'    => $OUT
		);

		// Load footer template
		if (getRequestParameter('type') == 'deleted') {
			// Delete now button
			loadTemplate('admin_list_task_delete', false, $content);
		} else {
			// Normal footer
			loadTemplate('admin_list_task', false, $content);
		}
	}
} // END - if

// [EOF]
?>
